@@ -17,11 +17,11 @@ FCGI::Buffer - Verify, Cache and Optimise FCGI Output
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -458,7 +458,7 @@ sub DESTROY {
 					# version in the cache
 					my $c;
 					if(defined($headers) && length($headers)) {
-						$c = $headers . "\r\n" . join("\r\n", @{$self->{o}});
+						$c = "$headers\r\n" . join("\r\n", @{$self->{o}});
 					} else {
 						$c = join("\r\n", @{$self->{o}});
 					}
@@ -483,7 +483,7 @@ sub DESTROY {
 				# if($headers !~ /^Expires: /m))) {
 				# }
 				if($self->{logger}) {
-					$self->{logger}->debug("store $key in the cache, age = ", $self->{cache_age});
+					$self->{logger}->debug("Store $key in the cache, age = ", $self->{cache_age}, ' ', length($cache_hash->{'body'}), ' bytes');
 				}
 				$self->{cache}->set($key, Storable::freeze($cache_hash), $self->{cache_age});
 				if($self->{generate_last_modified}) {
@@ -581,7 +581,7 @@ sub DESTROY {
 				my $i = 1;
 				$self->{logger}->trace('Stack Trace');
 				while((my @call_details = (caller($i++)))) {
-					$self->{logger}->trace($call_details[1] . ':' . $call_details[2] . ' in function ' . $call_details[3]);
+					$self->{logger}->trace($call_details[1], ':', $call_details[2], ' in function ', $call_details[3]);
 				}
 			}
 			CORE::warn(@_);     # call the builtin warn as usual
@@ -593,9 +593,10 @@ sub DESTROY {
 				my $mess = join("\r\n", @{$self->{o}});
 				$mess =~ /[^\x00-\xFF]/;
 				open(my $fout, '>>', '/tmp/NJH');
-				print $fout "$widemess:\n";
-				print $fout $mess;
-				print $fout 'x' x 40 . "\n";
+				print $fout "$widemess:\n",
+					$mess,
+					'x' x 40,
+					"\n";
 				close $fout;
 			}
 		}
@@ -629,7 +630,6 @@ sub _check_modified_since {
 		if($self->{logger}) {
 			$self->{logger}->info("$$params{since} is not a valid date");
 		}
-		# IF_MODIFIED_SINCE isn't a valid data
 		return;
 	}
 
@@ -664,6 +664,7 @@ sub _check_modified_since {
 sub _optimise_content {
 	my $self = shift;
 
+	# FIXME: regex bad, HTML parser good
 	# Regexp::List - wow!
 	$self->{body} =~ s/(((\s+|\r)\n|\n(\s+|\+)))/\n/g;
 	# $self->{body} =~ s/\r\n/\n/gs;
@@ -749,7 +750,7 @@ sub _generate_key {
 				foreach my $h2(split(/\r?\n/, $headers)) {
 					my ($h2_name, $h2_value) = split /\:\s*/, $h2, 2;
 					if($h2_name eq $h1_value) {
-						$key .= '::' . $h2_value;
+						$key .= "::$h2_value";
 						last;
 					}
 				}
@@ -816,6 +817,11 @@ Init allows a reference of the options to be passed. So both of these work:
 Generally speaking, passing by reference is better since it copies less on to
 the stack.
 
+If you give a cache to init() then later give cache => undef,
+the server side cache is no longer used.
+This is useful when you find an error condition when creating your HTML
+and decide that you no longer wish to store the output in the cache.
+
 =cut
 
 sub init {
@@ -858,7 +864,7 @@ sub init {
 			Carp::carp "Too late to call init, $pos characters have been printed";
 		}
 	}
-	if(defined($params{cache}) && $self->can_cache()) {
+	if(exists($params{cache}) && $self->can_cache()) {
 		if(defined($ENV{'HTTP_CACHE_CONTROL'})) {
 			my $control = $ENV{'HTTP_CACHE_CONTROL'};
 			if(defined($self->{logger})) {
@@ -874,7 +880,18 @@ sub init {
 			}
 		}
 		$self->{cache_age} ||= $params{cache_age};
-		$self->{cache} = $params{cache};
+		if((!defined($params{cache})) && defined($self->{cache})) {
+			if(defined($self->{logger})) {
+				if($self->{cache_key}) {
+					$self->{logger}->debug('disabling cache ', $self->{cache_key});
+				} else {
+					$self->{logger}->debug('disabling cache');
+				}
+			}
+			delete $self->{cache};
+		} else {
+			$self->{cache} = $params{cache};
+		}
 		if(defined($params{cache_key})) {
 			$self->{cache_key} = $params{cache_key};
 		}
